### Question: Improve Data Processing

#### Task 1 {#sec:task1}

Implement data normalization for the dataset.
<obs author="JMF" date="1/8/25 4:17pm">implemented the normalization! Make sure *markdown* still **works** $\frac{x}{y}$</obs>
Let's also make sure that this $x^2$ is rendered as math with mathjax!!
Also make sure that we have *italics* and **bold**.

![](end_vs_he_sketch.jpg)

#### Task 2 {#sec:task2}

Write visualization routines for exploratory analysis.

```{python}
from numpy import r_
from pylab import plot, legend
plot(r_[0:10], label='a line!')
legend()
```
